using AipGateway.AIP;
using AipGateway.API.Domain.Models.Request;
using AipGateway.API.Domain.Models.Response;

namespace AipGateway.API.Services
{
    public interface IApiFileService
    {
        Task<ResponseInfo> GetInfo(RequestFile req);
        Task<ResponseFile> SetLabel(RequestFileSet req);
        Task<ResponseFile> DelLabel(RequestFileDel req);
        Task<ResponseFile> SetProtection(RequestFileSet req);
        Task<ResponseFile> DelProtection(RequestFileDel req);
        Task<ResponseFile> SetLabelProtection(RequestFileAllSet req);
        Task<ResponseFile> DelLabelProtection(RequestFileDel req);

    }
}
